Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(358)

Unified Diff: net/quic/crypto/proof_source.h

Issue 1765603002: Add QUIC 31 in which the server's proof covers both the static server config as well as a hash of t… (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/crypto/crypto_utils.cc ('k') | net/quic/crypto/proof_source_chromium.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/crypto/proof_source.h
diff --git a/net/quic/crypto/proof_source.h b/net/quic/crypto/proof_source.h
index d2b4859095f165f780841cbb9bf2d1a6464c123a..74b9df3c7e0711a34cefafa49b078b90178c6c8b 100644
--- a/net/quic/crypto/proof_source.h
+++ b/net/quic/crypto/proof_source.h
@@ -10,6 +10,7 @@
#include "base/memory/ref_counted.h"
#include "net/base/net_export.h"
+#include "net/quic/quic_protocol.h"
namespace net {
@@ -55,10 +56,14 @@ class NET_EXPORT_PRIVATE ProofSource {
// the ProofSource retains ownership of the contents of |out_certs|. The
// expectation is that they will be cached forever.
//
// The signature values should be cached because |server_config| will be
// somewhat static. However, since they aren't bounded, the ProofSource may
// wish to evicit entries from that cache, thus the caller takes ownership of
// |*out_signature|.
//
// |hostname| may be empty to signify that a default certificate should be
// used.
@@ -69,6 +74,8 @@ class NET_EXPORT_PRIVATE ProofSource {
virtual bool GetProof(const IPAddress& server_ip,
const std::string& hostname,
const std::string& server_config,
+ QuicVersion quic_version,
+ base::StringPiece chlo_hash,
bool ecdsa_ok,
scoped_refptr<Chain>* out_chain,
std::string* out_signature,
@@ -55,10 +56,14 @@ class NET_EXPORT_PRIVATE ProofSource {
// expectation is that they will be cached forever.
//
- // The signature values should be cached because |server_config| will be
- // somewhat static. However, since they aren't bounded, the ProofSource may
- // wish to evicit entries from that cache, thus the caller takes ownership of
- // |*out_signature|.
+ // For version before QUIC_VERSION_30, the signature values should be cached
+ // because |server_config| will be somewhat static. However, since they aren't
+ // bounded, the ProofSource may wish to evicit entries from that cache, thus
+ // the caller takes ownership of |*out_signature|.
+ //
+ // For QUIC_VERSION_30 and later, the signature depends on |chlo_hash|
+ // which means that the signature can not be cached. The caller takes
+ // ownership of |*out_signature|.
//
// |hostname| may be empty to signify that a default certificate should be
« no previous file with comments | « net/quic/crypto/crypto_utils.cc ('k') | net/quic/crypto/proof_source_chromium.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698